@@ -4,4 +4,5 @@ from .enums import Fmi3Causality, Fmi3Initial, Fmi3Variability
 from .fmi3slave import Fmi3Slave
 from .variables import Boolean, Enumeration, Int32, Int64, UInt64, Float64, String, Dimension
 from .default_experiment import DefaultExperiment
-from .type_definitions import TypeDefinitions, Item, EnumerationType
+from .variable_types import Float64Type, EnumerationType
+from .unit import BaseUnit, Unit
