@@ -47,10 +47,10 @@ struct Component
         modelError = 1 << 12,
         modelFatal = 1 << 13,
     };
-    Component(cppfmu::FMIString instanceName,
+    Component(cppfmu::FMIComponentEnvironment instanceEnvironment,
         cppfmu::FMICallbackLogger logCallback,
         cppfmu::FMIBoolean loggingOn) : loggerSettings{std::make_shared<cppfmu::Logger::Settings>()},
-        logger{this, instanceName, logCallback, loggerSettings}, lastSuccessfulTime{std::numeric_limits<cppfmu::FMIReal>::quiet_NaN()}
+        logger{instanceEnvironment, logCallback, loggerSettings}, lastSuccessfulTime{std::numeric_limits<cppfmu::FMIFloat64>::quiet_NaN()}
     {
         loggerSettings->debugLoggingEnabled = (loggingOn == cppfmu::FMITrue);
     }
@@ -62,7 +62,7 @@ struct Component
 
     // Co-simulation
     std::unique_ptr<cppfmu::SlaveInstance> slave;
-    cppfmu::FMIReal lastSuccessfulTime;
+    cppfmu::FMIFloat64 lastSuccessfulTime;
 };
 } // namespace
 
@@ -96,7 +96,8 @@ fmi3Instance fmi3InstantiateCoSimulation(
     fmi3IntermediateUpdateCallback intermediateUpdate )
 {
     try {
-        auto component = new Component(instanceName,
+        auto component = new Component(
+            environment,
             logMessage,
             loggingOn);
         component->slave = CppfmuInstantiateSlave(
@@ -280,7 +281,7 @@ fmi3Status fmi3GetFloat64(
 {
     const auto component = reinterpret_cast<Component*>(c);
     try {
-        component->slave->GetReal(vr, nvr, values, nValues);
+        component->slave->GetFloat64(vr, nvr, values, nValues);
         return fmi3OK;
     } catch (const cppfmu::FatalError& e) {
         component->logger.Log(fmi3Fatal, "", e.what());
@@ -300,7 +301,27 @@ fmi3Status fmi3GetInt32(
 {
     const auto component = reinterpret_cast<Component*>(c);
     try {
-        component->slave->GetInteger(vr, nvr, values);
+        component->slave->GetInt32(vr, nvr, values);
+        return fmi3OK;
+    } catch (const cppfmu::FatalError& e) {
+        component->logger.Log(fmi3Fatal, "", e.what());
+        return fmi3Fatal;
+    } catch (const std::exception& e) {
+        component->logger.Log(fmi3Error, "", e.what());
+        return fmi3Error;
+    }
+}
+
+fmi3Status fmi3GetInt64(
+    fmi3Instance c,
+    const fmi3ValueReference vr[],
+    size_t nvr,
+    fmi3Int64 values[],
+    size_t nValues)
+{
+    const auto component = reinterpret_cast<Component*>(c);
+    try {
+        component->slave->GetInt64(vr, nvr, values);
         return fmi3OK;
     } catch (const cppfmu::FatalError& e) {
         component->logger.Log(fmi3Fatal, "", e.what());
@@ -381,7 +402,7 @@ fmi3Status fmi3SetFloat64(
 {
     const auto component = reinterpret_cast<Component*>(c);
     try {
-        component->slave->SetReal(vr, nvr, value, nValues);
+        component->slave->SetFloat64(vr, nvr, value, nValues);
         return fmi3OK;
     } catch (const cppfmu::FatalError& e) {
         component->logger.Log(fmi3Fatal, "", e.what());
@@ -401,7 +422,27 @@ fmi3Status fmi3SetInt32(
 {
     const auto component = reinterpret_cast<Component*>(c);
     try {
-        component->slave->SetInteger(vr, nvr, values);
+        component->slave->SetInt32(vr, nvr, values);
+        return fmi3OK;
+    } catch (const cppfmu::FatalError& e) {
+        component->logger.Log(fmi3Fatal, "", e.what());
+        return fmi3Fatal;
+    } catch (const std::exception& e) {
+        component->logger.Log(fmi3Error, "", e.what());
+        return fmi3Error;
+    }
+}
+
+fmi3Status fmi3SetInt64(
+    fmi3Instance c,
+    const fmi3ValueReference vr[],
+    size_t nvr,
+    const fmi3Int64 values[],
+    size_t nValues)
+{
+    const auto component = reinterpret_cast<Component*>(c);
+    try {
+        component->slave->SetInt64(vr, nvr, values);
         return fmi3OK;
     } catch (const cppfmu::FatalError& e) {
         component->logger.Log(fmi3Fatal, "", e.what());
@@ -659,8 +700,6 @@ NOT_IMPLEMENTED_GETTER(Int8, fmi3Int8);
 NOT_IMPLEMENTED_SETTER(Int8, fmi3Int8);
 NOT_IMPLEMENTED_GETTER(Int16, fmi3Int16);
 NOT_IMPLEMENTED_SETTER(Int16, fmi3Int16);
-NOT_IMPLEMENTED_GETTER(Int64, fmi3Int64);
-NOT_IMPLEMENTED_SETTER(Int64, fmi3Int64);
 
 NOT_IMPLEMENTED_GETTER(UInt8, fmi3UInt8);
 NOT_IMPLEMENTED_SETTER(UInt8, fmi3UInt8);
